---
title: testing
---

# `marvin.utilities.testing`

## Functions

### `assert_llm_equal`
```python
def assert_llm_equal(result: Any, expected: Any) -> bool
```

---

**Parent Module:** [`utilities`](marvin-utilities)
